#!/bin/sh

# Build script for Wormux
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://info.sonicretro.org/Gens/GS


set -e


SOFTNAME=wormux
VERSION=0.9.2.1
ZENVER=64
BUILD=1

CATEGORY=extra/games

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILES=(
	$SOFTNAME-$VERSION.tar.bz2
	$SOFTNAME.png
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://download.gna.org/wormux
	$HOSTURL
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
)

DOC=(
	$SOFTDIR/AUTHORS
	$SOFTDIR/ChangeLog
	$SOFTDIR/COPYING
	$SOFTDIR/INSTALL
	$SOFTDIR/README
	$SOFTDIR/TODO
)

EXTRADEPS=(
)

LESSDEPS=(
	'x11-driver-nvidia-rt'
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

./configure \
	--prefix=/usr \
	--localstatedir=/var \
	--sysconfdir=/etc \
	--mandir=/usr/man \
	--infodir=/usr/info \
	--disable-static

sed -i -e "s:-O2:$FLAGS:g" Makefile
sed -i -e "s:-O2:$FLAGS:g" data/Makefile
sed -i -e "s:-O2:$FLAGS:g" doc/Makefile
sed -i -e "s:-O2:$FLAGS:g" po/Makefile
sed -i -e "s:-O2:$FLAGS:g" src/Makefile

make -j2
make DESTDIR=$PKGDIR install


sed -i -e 's/Icon=wormux_128x128.png/Icon=wormux/' \
	$PKGDIR/usr/share/applications/wormux.desktop

mkdir -pv $PKGDIR/usr/share/icons/hicolor/scalable/apps
( cd $PKGDIR/usr/share/icons/hicolor/scalable/apps
ln -svf ../../../../wormux/wormux.svg wormux.svg )

mkdir -pv $PKGDIR/usr/share/icons/hicolor/32x32/apps
( cd $PKGDIR/usr/share/icons/hicolor/32x32/apps
ln -svf ../../../../wormux/wormux_32x32.png wormux.png )

mkdir -pv $PKGDIR/usr/share/icons/hicolor/48x48/apps
cp -v $CWD/${SRCFILES[1]} \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/wormux.png

mkdir -pv $PKGDIR/usr/share/icons/hicolor/128x128/apps
( cd $PKGDIR/usr/share/icons/hicolor/128x128/apps
ln -svf ../../../../wormux/wormux_128x128.png wormux.png )

mkdir -pv $PKGDIR/usr/share/icons/hicolor/256x256/apps
( cd $PKGDIR/usr/share/icons/hicolor/256x256/apps
ln -svf ../../../../wormux/wormux_256x256.png wormux.png )


( cd $PKGDIR
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null )


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	   #|-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - Clone of the Worms(R) series of games developed by Team17
$SOFTNAME:
$SOFTNAME: Wormux is free software clone of the Worms(R) series of games,
$SOFTNAME: developed by Team17. Worms was created in 1990, the goal of the
$SOFTNAME: game consisting of a several teams of "worms" fighting to the death
$SOFTNAME: on a 2D map. Wormux is heavily influenced by all games in this genre,
$SOFTNAME: including Scorched Earth and Liero.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$CWD/${SRCFILES[1]} \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions and ownership
fakeroot chown -R root:root .
find . -perm 777 -exec fakeroot chmod 755 {} \;
find . -perm 775 -exec fakeroot chmod 755 {} \;
find . -perm 666 -exec fakeroot chmod 644 {} \;
find . -perm 664 -exec fakeroot chmod 644 {} \;
find . -perm 600 -exec fakeroot chmod 644 {} \;
find . -perm 444 -exec fakeroot chmod 644 {} \;
find . -perm 400 -exec fakeroot chmod 644 {} \;
find . -perm 440 -exec fakeroot chmod 644 {} \;
find . -perm 511 -exec fakeroot chmod 755 {} \;
find . -perm 711 -exec fakeroot chmod 755 {} \;
find . -perm 555 -exec fakeroot chmod 755 {} \;


/sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKG
